#define COMPILE_WITH_R 1
#include <vector>

using namespace std;

double teststatistics(vector<double> y1, vector<double> y2);

void test(int *ndouble1, int *ndouble2, double* y1, double* y2, double* test_statistics);

double foo(vector<double> y1, vector<double> y2, int num);

void vexler(int *ndouble1, int *ndouble2, double* y1, double* y2, double* mc, double* test_staistics, double* p_value);

